@@ -25,18 +25,20 @@ class _Folds:
 
 # Class to hold and train many models (CB, XGB and LGB) on the same dataset
 class GBMFitter:
+    """Generates models in a CV manner for all 3 libraries algorithms
+
+        Parameters
+        ----------
+        cb_data: a list of CatBoost params and iterations dicts. Syntax is [{'params':params, 'n':iteration}]
+        xgb_data: a list of XGBoost params and iterations dicts. Syntax is [{'params':params, 'n':iteration}]
+        lgb_data: a list of Light GBM params and iterations dicts. Syntax is [{'params':params, 'n':iteration}]
+        cv_strategy:
+        use_rounders : boolean
+            To indicate to use rounders """
     def __init__(self, cb_data=None, xgb_data=None, lgb_data=None, cv_strategy=None, cv_groups=None, use_rounders=False,
                  metrics=['rmse'], verbose=1, logfile=None):
-        """Generates models in a CV manner for all 3 libraries algorithms
 
-        Inputs:
-            - cb_data: a list of CatBoost params and iterations dicts. Syntax is [{'params':params, 'n':iteration}]
-            - xgb_data: a list of XGBoost params and iterations dicts. Syntax is [{'params':params, 'n':iteration}]
-            - lgb_data: a list of Light GBM params and iterations dicts. Syntax is [{'params':params, 'n':iteration}]
-            - folds: Number of folds for CV
-            - feature_selection: the threshold to select features. If -1, takes all
-            - cv_strategy:
-            - use_rounders: boolean to indicate to use rounders """
+
         self.training_data = {'CB': cb_data, 'XGB': xgb_data, 'LGB': lgb_data}
         self.models = {'CB': [], 'XGB': [], 'LGB': []}  # for each category, generates folds models
         self.oof = {'CB': [], 'XGB': [], 'LGB': []}
@@ -62,14 +64,22 @@ class GBMFitter:
 
     def fit(self, X, y, categorical=None, feature_selection=-1, skip_CB=False, skip_XGB=False, skip_LGB=False, num_boost_rounds=5000,
             early_stopping=None):
-        """Generates models in a CV manner for all 3 libraries algorithms
+        """
+        Generates models in a CV manner for all 3 libraries algorithms
 
-        Inputs:
-            - X: Dataframe with features
-            - y: target variable
-            - categorical: a list of categorical variables
-            - folds: Number of folds for CV
-            - feature_selection: the threshold to select features. If -1, takes all"""
+        Parameters
+        ----------
+        X: pd.Dataframe
+            Training data
+        y: Series or numpy array
+            Target variable
+        categorical : list of str
+            A list of categorical variables
+        folds : int
+            Number of folds for CV
+        feature_selection : float
+            The threshold to select features. If -1, takes all
+        """
 
         # Fits the data for each library algorithm
         if not skip_CB:
@@ -85,15 +95,16 @@ class GBMFitter:
         """ Fits data into the algorithms. Generates a model per fold, and stores a
         tuple of (model, rounder) into self.models for each fold.
 
-        Inputs:
-            - library: String indicating the library to fit the model for (CB, XGB or LGB)
-            - X: Dataframe with features
-            - y: target variable
-            - categorical: a list of categorical variables
-            - folds: Number of folds for CV
-            - feature_selection: the threshold to select features. If -1, takes all
-            - num_boost_rounds: Default boosting rounds
-            - early_stopping: Default early_stopping
+        Parameters
+        ----------
+        library: String indicating the library to fit the model for (CB, XGB or LGB)
+        X: Dataframe with features
+        y: target variable
+        categorical: a list of categorical variables
+        folds: Number of folds for CV
+        feature_selection: the threshold to select features. If -1, takes all
+        num_boost_rounds: Default boosting rounds
+        early_stopping: Default early_stopping
         """
 
         if not self.training_data[library]:
@@ -149,18 +160,27 @@ class GBMFitter:
                 self._train(library, model, X_data, y, categorical)  # TODO to be tested
 
     def _train(self, library, model_data, train, validation=None, categorical=[], num_boost_rounds=5000, early_stopping=None, encoder=None):
-        """ Trains a mode on training data, calculates predictions for training and for validation,
+        """
+        Trains a mode on training data, calculates predictions for training and for validation,
         and also creates and fits the corresponding OptRounder object.
 
-        Inputs:
-            - library: String indicating the library to calculate the model for (CB, XGB or LGB)
-            - model_params: List with model params[0] and number of rounds[1]
-            - train: Tuple with train data, train[0] is X and train[1] is y
-            - validation: Validation data, validation[0] is X and validation[1] is y
-            - categorical: List with the categorical variables
-            - num_boost_rounds: Default boosting rounds. Could be overriden by individual values in model_data['n]
-            - early_stopping: Default early_stopping. Could be overriden by individual values in model_data['es']
-            """
+        Parameters
+        ----------
+        library : str
+            String indicating the library to calculate the model for (CB, XGB or LGB)
+        model_params :
+            List with model params[0] and number of rounds[1]
+        train : tuple of (pd.DataFrame, Series or numpy array)
+            Tuple with train data, train[0] is X and train[1] is y
+        validation : tuple of (pd.DataFrame, Series or numpy array), optional
+            Validation data, validation[0] is X and validation[1] is y
+        categorical : list of str
+            List with the categorical variables, optional
+        num_boost_rounds : int, defaults to 5000
+            Default boosting rounds. Could be overriden by individual values in model_data['n]
+        early_stopping : int
+            Default early_stopping. Could be overriden by individual values in model_data['es']
+        """
 
         # Get train and validation sets
         start = time.time()
@@ -268,24 +288,35 @@ class GBMFitter:
         return y_pred_val
 
     def get_oof(self, library):
-        """Returns OOF for
+        """
+        Returns OOF for
 
-            Inputs:
-                - library: Whether 'CB', 'XGB' or 'LGB'
+        Parameters
+        ----------
+        library : str
+            Whether 'CB', 'XGB' or 'LGB'
 
-            Output:
-                - Returns a list of Numpy arrays. One array per configuration"""
+        Returns
+        -------
+        list of ndarray
+            One array per configuration"""
         return self.oof[library]
 
     def predict(self, X, categorical=None, mean_function=None):
-        """Predicts the regression value without calculating a class
+        """
+        Predicts the regression value without calculating a class
 
-        Inputs:
-            - X: Data to predict a class for
-            - mean_function: Function to run as part of .apply, to average the class result from all columns. It is included in a new column
+        Parameters
+        ----------
+        X : pd.DataFrame
+            Data to predict a class for
+        mean_function : function
+            Function to run as part of .apply, to average the class result from all columns. It is included in a new column
 
-        Output:
-            - Returns a Pandas DataFrame with all the predicted class for each sample (row) and each model (column)"""
+        Returns
+        -------
+        pd.DataFrame
+            All the predicted class for each sample (row) and each model (column)"""
         df = pd.DataFrame()
 
         for i in range(0, len(self.models['CB'])):
@@ -313,12 +344,17 @@ class GBMFitter:
     def predict_class(self, X, mean_function=None):
         """Predicts a class for the given data X. The class is determined by the optimizer, which has been previously fitted.
 
-        Inputs:
-            - X: Data to predict a class for
-            - mean_function: Function to run as part of .apply, to average the class result from all columns. It is included in a new column
+        Parameters
+        ----------
+        X : pd.DataFrame
+            Data to predict a class for
+        mean_function : function
+            Function to run as part of .apply, to average the class result from all columns. It is included in a new column
 
-        Output:
-            - Returns a Pandas DataFrame with all the predicted class for each sample (row) and each model (column)"""
+        Returns
+        -------
+        pd.DataFrame
+            All the predicted class for each sample (row) and each model (column)"""
         df = pd.DataFrame()
 
         # Predict values for every calculated model for Catboost
@@ -346,9 +382,13 @@ class GBMFitter:
         return df
 
     def log(self, message):
-        """ Log training ouput into console and file
-            input:
-                message: message to be logged
+        """
+        Log training ouput into console and file
+
+        Parameters
+        ----------
+        message : str
+            message to be logged
         """
         if self.verbose > 0:
             print(message)
